==> bee-1.11-sources.jar: org/teasoft/bee/osql/DatabaseConst.java <==
package org.teasoft.bee.osql;

/**
 * Database Name Const.
 * @author Kingstar
 * @since  1.0
 */
public final class DatabaseConst {
	
	private DatabaseConst() {}

	public static final String MYSQL = "MySQL";
	public static final String MariaDB = "MariaDB";
	public static final String ORACLE = "Oracle";
	public static final String SQLSERVER = "Microsoft SQL Server";

	public static final String H2 = "H2";
	public static final String SQLite = "SQLite";
	public static final String PostgreSQL = "PostgreSQL";

	public static final String Cubrid = "Cubrid";
	public static final String DB2400 = "DB2 UDB for AS/400";
	public static final String DB2 = "DB2"; //todo
	public static final String Derby = "Apache Derby";
	public static final String Firebird = "Firebird";
	public static final String FrontBase = "FrontBase";

	public static final String HSQL = "HSQL Database Engine";
	public static final String Informix = "Informix Dynamic Server";
	public static final String Ingres = "Ingres";
	public static final String JDataStore = "JDataStore";
	public static final String Mckoi = "Mckoi";
	public static final String MimerSQL = "MimerSQL";
	public static final String Pointbase = "Pointbase";

	public static final String SAPDB = "SAPDB";
	public static final String Sybase = "Sybase SQL Server";
	public static final String Teradata = "Teradata";
	public static final String TimesTen = "TimesTen";
	
	//NoSql
	public static final String Cassandra = "Cassandra";
	public static final String Hbase = "Hbase";
	public static final String Hypertable= "Hypertable";
	
	public static final String MongoDB= "MongoDB";
	public static final String CouchDB = "CouchDB";

}

==> bee-1.17-sources.jar: org/teasoft/bee/osql/DatabaseConst.java <==
package org.teasoft.bee.osql;

/**
 * Database Name Const.
 * @author Kingstar
 * @since  1.0
 */
public final class DatabaseConst {
	
	private DatabaseConst() {}

	public static final String MYSQL = "MySQL";
	public static final String MariaDB = "MariaDB";
	public static final String ORACLE = "Oracle";
	public static final String SQLSERVER = "Microsoft SQL Server";

	public static final String H2 = "H2";
	public static final String SQLite = "SQLite";
//	public static final String AndroidSQLite = "AndroidSQLite";
//	public static final String HarmonySQLite = "HarmonySQLite";
	public static final String PostgreSQL = "PostgreSQL";

	public static final String Cubrid = "Cubrid";
	public static final String DB2400 = "DB2 UDB for AS/400";
	public static final String DB2 = "DB2"; //todo
	public static final String Derby = "Apache Derby";
	public static final String Firebird = "Firebird";
	public static final String FrontBase = "FrontBase";

	public static final String HSQL = "HSQL Database Engine";
	public static final String Informix = "Informix Dynamic Server";
	public static final String Ingres = "Ingres";
	public static final String JDataStore = "JDataStore";
	public static final String Mckoi = "Mckoi";
	public static final String MimerSQL = "MimerSQL";
	public static final String Pointbase = "Pointbase";

	public static final String SAPDB = "SAPDB";
	public static final String Sybase = "Sybase SQL Server";
	public static final String Teradata = "Teradata";
	public static final String TimesTen = "TimesTen";
	
	public static final String DM ="DM DBMS";
	public static final String Kingbase ="KingbaseES";
	
	//NoSql
	public static final String Cassandra = "Cassandra";
	public static final String Hbase = "Hbase";
	public static final String Hypertable= "Hypertable";
	
	public static final String MongoDB= "MongoDB";
	public static final String CouchDB = "CouchDB";

}
